<template>
  <div class="sticky top-0 h-full p-6 bg-[#ebe5ff]" style="height: calc(100% - 10rem);padding-bottom: 4rem;">
    <div class="relative flex justify-between mb-3">
      <div></div>
      <h4 class="font-semibold text-lg mt-3 text-black-600 block whitespace-nowrap">Pilih Post</h4>
      <button
      @click="chat.toggleSharePost= !chat.toggleSharePost"
      class="btn btn-ghost btn-circle p-2.5">
        <svg xmlns="http://www.w3.org/2000/svg" class="fill-current text-black-600" viewBox="0 0 24 24">
          <path
              d="M19,6.41L17.59,5L12,10.59L6.41,5L5,6.41L10.59,12L5,17.59L6.41,19L12,13.41L17.59,19L19,17.59L13.41,12L19,6.41Z"/>
        </svg>
      </button>
    </div>

    <div class="block relative h-full m-auto w-auto bg-white">
      <perfect-scrollbar @ps-y-reach-end="onScrollEnd">
        <div class="relative block w-full">
          <div class="grid grid-cols-3 xl:grid-cols-4 gap-1">
            <div v-if="postIsLoading" class="w-6 h-6">
              <IcLoading color="primary"/>
            </div>
            <div 
              v-else
              v-for="(post, postIndex) in posts"
              :key="postIndex"
              class="relative block overflow-hidden transition-all duration-200 bg-white"
            >
            <label class="relative flex items-center cursor-pointer">
                <!-- The actual input -->
                <input
                  type="radio"
                  name="tiktok"
                  class="peer hidden"
                  v-model="selectedPost"
                  :value="post"
                />

                <!-- Clickable Image -->
                <div
                  class="relative w-full min-h-[300px] bg-cover bg-center flex items-end p-2 peer-checked:ring-2 peer-checked:ring-blue-500"
                  :style="{ backgroundImage: `url('${post?.thumbnail_url}')` }"
                  @click="selectedPost = post"
                >
                  <!-- Custom Radio Button in Top Right -->
                  <label class="absolute top-2 right-2 cursor-pointer">
                    <div
                      class="w-5 h-5 border-2 border-gray-300 rounded-full bg-white flex items-center justify-center"
                      :class="{ 'border-primary bg-primary': selectedPost?.item_id === post.item_id }"
                    >
                      <svg
                        v-if="selectedPost?.item_id === post.item_id"
                        xmlns="http://www.w3.org/2000/svg"
                        width="10"
                        height="32"
                        fill="#7646FC"
                        viewBox="0 0 256 256"
                      >
                        <path
                          d="M243.31,90.91l-128.4,128.4a16,16,0,0,1-22.62,0l-71.62-72a16,16,0,0,1,0-22.61l20-20a16,16,0,0,1,22.58,0L104,144.22l96.76-95.57a16,16,0,0,1,22.59,0l19.95,19.54A16,16,0,0,1,243.31,90.91Z"
                        ></path>
                      </svg>
                    </div>
                  </label>

                  <!-- Video Views -->
                  <span class="text-white text-sm py-1 rounded flex flex-row items-center gap-1">
                    <svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" fill="#ffffff" viewBox="0 0 256 256">
                      <path
                        d="M232.4,114.49,88.32,26.35a16,16,0,0,0-16.2-.3A15.86,15.86,0,0,0,64,39.87V216.13A15.94,15.94,0,0,0,80,232a16.07,16.07,0,0,0,8.36-2.35L232.4,141.51a15.81,15.81,0,0,0,0-27ZM80,215.94V40l143.83,88Z"
                      ></path>
                    </svg>
                    {{ post.video_views }}
                  </span>
                </div>
              </label>
            </div>
          </div>
        </div>
      </perfect-scrollbar>

      <div :class="`absolute transition-all duration-200 ${isListLoading ? 'bottom-2' : '-bottom-20'} w-full  z-40 flex items-center justify-center`">
        <span class="w-7 h-7 bg-white rounded-full shadow-lg flex items-center justify-center">
          <svg class="animate-spin h-full w-full text-scheme-primary" xmlns="http://www.w3.org/2000/svg"
                fill="none" viewBox="0 0 24 24">
          <circle class="opacity-25" cx="12" cy="12" r="10" stroke="currentColor" stroke-width="4"></circle>
          <path class="opacity-75" fill="currentColor"
                d="M4 12a8 8 0 018-8V0C5.373 0 0 5.373 0 12h4zm2 5.291A7.962 7.962 0 014 12H0c0 3.042 1.135 5.824 3 7.938l3-2.647z"></path>
        </svg>
        </span>
      </div>
    </div>

    
  </div>
  <div class="relative block overflow-hidden h-20 w-full bg-[#ebe5ff]">
      <div
          :class="`${isExpired ? 'disabled cursor-not-allowed' : ''}  relative flex justify-between items-center align-middle h-full`">

        <div class="flex gap-4 items-center w-full h-full py-3 relative px-3">
          <button
              @click="sendPost"
              :class="`right-8 absolute overflow-hidden w-12 h-12 bg-scheme-primary transition duration-300 hover:bg-opacity-80 p-3 rounded-full group ${!selectedPost ? 'disabled cursor-not-allowed' : ''}`"
              :disabled="!selectedPost"
              id="btn-sendMessage">
            <IcLoading v-if="isLoading"/>
            <IcPaperPlane v-else/>
          </button>
        </div>
      </div>
    </div>
</template>
<script setup lang="ts">

import {useChatListStore} from "../../../stores/chat_list"
import _ from 'lodash'

//@ts-ignore

import {onMounted, onUnmounted, ref, watch} from "vue";
import helpers from "../../../utils/helpers";
import IcLoading from "../../Icon/IcLoading.vue";
import IcPaperPlane from "../../Icon/IcPaperPlane.vue";

const isExpired = ref()
const isLoading = ref(false)
const isEndPage = ref(false)
const selectedSurvey = ref()
const isListLoading = ref(false)
const currentPage = ref(1)
const chat = useChatListStore()
const selectedPost = ref()
const emit = defineEmits(['surveyData'])
const isFetching = ref(true);
const posts = ref([])
const cursor = ref(null)
const hasMore = ref(true)
const postIsLoading = ref(true)

const sendPost = async () => {
    isLoading.value = true

    if (selectedPost.value != '') {

      const payload = {
        embed_url: selectedPost.value?.embed_url,
        item_id: selectedPost.value?.item_id,
      }

      await chat.sendSharePost(chat.detail.customer.user_chat_id, payload).then(async (resp) => {
        if ("code" in resp && resp.code == 200) {
          helpers.scrollToBottomChat()
        } else {
          // alert(resp)
        }
      })
    }

    chat.toggleSharePost = false
    isLoading.value = false
}

const onScrollEnd = async (event) => {
  if (hasMore.value && !isFetching.value) {
    isListLoading.value = true
    await chat.getSharePost(cursor.value, 12)
    .then((resp) => {
      if (resp.code === 200) {
        if (resp.data.videos.length > 0) {
          resp.data.videos.map((item) => {
            posts.value.push(item)
          })
          console.log(posts)
          hasMore.value = resp.data.hasMore
          cursor.value = resp.data.cursor
        } else {
          hasMore.value = resp.data.hasMore
          cursor.value = resp.data.cursor
        }
      }
    })
    isListLoading.value = false
  }
}

onUnmounted(() => {
  chat.toggleSharePost = false
})

onMounted(async () => {
  posts.value = []
  await chat.getSharePost(cursor.value, 12)
  .then((resp) => {
    if (resp.code === 200) {
      if (resp.data.videos.length > 0) {
        posts.value = resp.data.videos
        hasMore.value = resp.data.has_more
        cursor.value = resp.data.cursor
      }
    }
  }).finally(()=>{
    isFetching.value = false;
    postIsLoading.value = false;
  })
})

watch(selectedPost, (newValue) => {
  console.log("Selected Post ID:", newValue);
});

</script>
